@@ -1,7 +1,7 @@
 package Config::YUM;
 
 # I cannot live without this.
-use 5.008;
+use 5.008006;
 use strict;
 use warnings;
 
@@ -15,6 +15,7 @@ use FreezeThaw qw/thaw safeFreeze/;
 use Config::IniHash;
 use Hash::Merge qw/merge/;
 use File::Temp qw/tempfile/;
+use File::Remove qw/remove/;
 use Cache::File;
 use XML::LibXML;
 use Sort::Versions;
@@ -32,7 +33,7 @@ our @EXPORT = qw(
 );
 
 # Define our version, comes from CVS.
-(our $VERSION) = '$Revision: 1.10 $' =~ /([\d.]+)/;
+(our $VERSION) = '$Revision: 1.3 $' =~ /([\d.]+)/;
 
 # The new function is used to create an instance of this package.
 # You can define various things. Please have a look at the documentation
@@ -168,24 +169,16 @@ sub parse {
 				open($fh, $filename);
 				while(<$fh>) {
 					chomp;
-					unless($_ =~ /^#/) {
-						if($_) {
-							push @baseurls, $_
-						}
-					}
+					push @baseurls, $_;
 				}
 				close($fh);
-				unlink $filename;
+				remove $fh;
 				# Provide a baseurl
 				$self->{__yumconf}->{$section}->{baseurl} = $baseurls[0];
 				# Safe an array of baseurls extra (could be used to make the failover stuff)
-				$self->{__yumconf}->{$section}->{baseurls} = \@baseurls if @baseurls > 1;
+				$self->{__yumconf}->{$section}->{baseurls} = @baseurls if @baseurls > 1;
 				# Delete the mirrorlist from the hash, as we don't need it any more.
 				delete $self->{__yumconf}->{$section}->{mirrorlist};
-				# Make the substitutions...
-				$self->{__yumconf}->{$section}->{baseurl} = $self->substi($self->{__yumconf}->{$section}->{baseurl});
-				# Download/parse primary.xml.gz if defined to do so (at new)
-				$self->{__yumconf}->{$section}->{primary} = $self->read_primary($self->{__yumconf}->{$section}->{baseurl}.'/repodata/primary.xml.gz') if $self->{download_primary};
 			} else {
 				# Die, if we have no baseurl for some repo. We really should not continue
 				# if a repo has no baseurl. Also yum itself dies, if this happens, so we
@@ -247,7 +240,7 @@ sub read_primary($) {
 
 	# Remove the tempfile, as we don't need it any more and we
 	# clean up temps usually (arg. we REALLY should!)
-	unlink $filename;
+	remove $filename;
 
 	# Init the parser;
 	my $parser = XML::LibXML->new();
@@ -266,22 +259,17 @@ sub read_primary($) {
 		my $version = @{$child->getChildrenByTagName("version")}[0]->getAttribute("ver");
 		my $release = @{$child->getChildrenByTagName("version")}[0]->getAttribute("rel");
 		my $epoch   = @{$child->getChildrenByTagName("version")}[0]->getAttribute("epoch");
-		my $arch    = @{$child->getChildrenByTagName("arch")}[0]->textContent();
 		# This is black magic. :-)
 		# primary.xml.gz also lists older packages, if you don't have a very clean yum-repo
 		# This functions checks the epoch first and afterward the version/release...
 		# Might be no bad idea to also save the old packages to the hash, but I didn't need
 		# this yet...
 		if($packages->{$name}) {
-			# prefer the basearch over all others
-			next if ($arch ne $self->{'basearch'} and
-					$packages->{$name}->{'arch'} eq $self->{'basearch'});
 			if($epoch > $packages->{$name}->{epoch}) {
 				$packages->{$name} = {
 					version => $version,
 					release => $release,
 					epoch   => $epoch,
-					arch    => $arch,
 				};
 			} else {
 				my $verel1 = $version . "-" . $release;
@@ -292,16 +280,6 @@ sub read_primary($) {
 							version => $version,
 							release => $release,
 							epoch   => $epoch,
-							arch    => $arch,
-						};
-					}
-				} elsif (versioncmp($verel1, $verel2) == 0) {
-					if ($packages->{$name}->{'arch'} ne $self->{'basearch'}) {
-						$packages->{$name} = {
-							version => $version,
-							release => $release,
-							epoch   => $epoch,
-							arch    => $arch,
 						};
 					}
 				}
@@ -311,7 +289,6 @@ sub read_primary($) {
 				version => $version,
 				release => $release,
 				epoch   => $epoch,
-				arch    => $arch,
 			};
 		}
 	}
@@ -352,7 +329,7 @@ sub get_include($) {
 		print $fh $data;
 		close($fh);
 		my $inc_hash = ReadINI($filename);
-		unlink $filename;
+		remove $filename;
 		return $inc_hash;
 	} else {
 		# Same here with ftp:
@@ -363,7 +340,7 @@ sub get_include($) {
 			print $fh $data;
 			close($fh);
 			my $inc_hash = ReadINI($filename);
-			unlink $filename;
+			remove $filename;
 			return $inc_hash;
 		} else {
 			# If it begins with slash, it can be directly read with ReadINI
@@ -536,6 +513,7 @@ RPM2
 LWP::UserAgent
 FreezeThaw
 File::Temp
+File::Remove
 Cache::File
 XML::LibXML
 Sort::Versions
